@@ -2,6 +2,7 @@ use std::{
     fmt::Display,
     ops::{Add, AddAssign},
     sync::atomic::{AtomicBool, AtomicU64, Ordering},
+    time::Duration,
 };
 
 use serde::Serialize;
@@ -24,7 +25,7 @@ pub mod __dep {
 }
 
 /// The context send to MultiBench::run()
-pub struct BenchContext<'a, C: BenchConfig> {
+pub struct Context<'a, C: BenchConfig> {
     pub thread_id: usize,
     pub thread_cnt: usize,
     pub config: &'a C,
@@ -32,7 +33,7 @@ pub struct BenchContext<'a, C: BenchConfig> {
     running: &'a AtomicBool,
 }
 
-impl<C: BenchConfig> BenchContext<'_, C> {
+impl<C: BenchConfig> Context<'_, C> {
     /// A barrier to ensure all threads start at exactly the same time,
     /// every run() should call context.wait_for_start() right after initialization or it will block forever.
     pub fn wait_for_start(&self) {
@@ -56,15 +57,25 @@ impl<C: BenchConfig> BenchContext<'_, C> {
     }
 }
 
-unsafe impl<C: BenchConfig> Send for BenchContext<'_, C> {}
-unsafe impl<C: BenchConfig> Sync for BenchContext<'_, C> {}
+unsafe impl<C: BenchConfig> Send for Context<'_, C> {}
+unsafe impl<C: BenchConfig> Sync for Context<'_, C> {}
 
 pub trait BenchResult:
     serde::Serialize + Default + AddAssign + Add<Output = Self> + Clone + Send + Sync + Display
 {
+    fn short_value(&self) -> usize;
+    fn normalize_time(self, dur: &Duration) -> Self;
 }
 
-impl BenchResult for usize {}
+impl BenchResult for usize {
+    fn short_value(&self) -> usize {
+        *self
+    }
+
+    fn normalize_time(self, dur: &Duration) -> usize {
+        ((self as f64) / dur.as_secs_f64()) as usize
+    }
+}
 
 pub trait BenchConfig: Clone + Serialize {
     fn name(&self) -> &String;
@@ -85,7 +96,7 @@ pub trait ShumaiBench: Send + Sync {
     /// Run concurrent benchmark
     /// Inside this function should call context.wait_for_start() to notify the main thread;
     /// it also blocks current thread until every thread is ready (i.e. issued context.wait_for_start())
-    fn run(&self, context: BenchContext<Self::Config>) -> Self::Result;
+    fn run(&self, context: Context<Self::Config>) -> Self::Result;
 
     /// clean up resources, if necessary
     fn cleanup(&self) -> Option<serde_json::Value>;
